Documentation
¶
Index ¶
- func NewBuildInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewBuildTemplateInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewClusterBuildTemplateInformer(client versioned.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredBuildInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredBuildTemplateInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredClusterBuildTemplateInformer(client versioned.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- type BuildInformer
- type BuildTemplateInformer
- type ClusterBuildTemplateInformer
- type Interface
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewBuildInformer ¶
func NewBuildInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewBuildInformer constructs a new informer for Build type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewBuildTemplateInformer ¶
func NewBuildTemplateInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewBuildTemplateInformer constructs a new informer for BuildTemplate type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewClusterBuildTemplateInformer ¶ added in v0.2.0
func NewClusterBuildTemplateInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewClusterBuildTemplateInformer constructs a new informer for ClusterBuildTemplate type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredBuildInformer ¶
func NewFilteredBuildInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredBuildInformer constructs a new informer for Build type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredBuildTemplateInformer ¶
func NewFilteredBuildTemplateInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredBuildTemplateInformer constructs a new informer for BuildTemplate type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredClusterBuildTemplateInformer ¶ added in v0.2.0
func NewFilteredClusterBuildTemplateInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredClusterBuildTemplateInformer constructs a new informer for ClusterBuildTemplate type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
Types ¶
type BuildInformer ¶
type BuildInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.BuildLister
}
BuildInformer provides access to a shared informer and lister for Builds.
type BuildTemplateInformer ¶
type BuildTemplateInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.BuildTemplateLister
}
BuildTemplateInformer provides access to a shared informer and lister for BuildTemplates.
type ClusterBuildTemplateInformer ¶ added in v0.2.0
type ClusterBuildTemplateInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.ClusterBuildTemplateLister
}
ClusterBuildTemplateInformer provides access to a shared informer and lister for ClusterBuildTemplates.
type Interface ¶
type Interface interface {
// Builds returns a BuildInformer.
Builds() BuildInformer
// BuildTemplates returns a BuildTemplateInformer.
BuildTemplates() BuildTemplateInformer
// ClusterBuildTemplates returns a ClusterBuildTemplateInformer.
ClusterBuildTemplates() ClusterBuildTemplateInformer
}
Interface provides access to all the informers in this group version.
func New ¶
func New(f internalinterfaces.SharedInformerFactory, namespace string, tweakListOptions internalinterfaces.TweakListOptionsFunc) Interface
New returns a new Interface.